Copy input/small.fasta to wherever you are going to submit this workflow before packaging and submitting this blast workflow

Also there seems to be an error with using the glob in blast_worker001.cwl & 2
I have left the previous output in a comment.

stderr has not been tested since it is still not implemented


